@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Depak;
 
-our $DATE = '2015-07-07'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2015-07-27'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -69,14 +69,16 @@ sub munge_script {
     $self->log_fatal(["Can't find depak in PATH"]) unless which("depak");
 
     # we use the depak CLI instead of App::depak because we want to use
-    # --config-profile
+    # --config-profile.
+    my $profile = $file->name;
+    $profile =~ s!.+[\\/]!!;
 
-    # since we're dealing with CLI, we need actual files
+    # since we're dealing with CLI, we need actual files. even a modified
+    # DZF:OnDisk might not have the actual file located in $file->name, so we
+    # write to tempfile first.
 
     my $source;
-    if ($file->isa("Dist::Zilla::File::OnDisk")) {
-        $source = $file->name;
-    } else {
+    {
         my ($fh, $filename) = tempfile();
         $source = $filename;
         write_binary($filename, $file->content);
@@ -93,13 +95,17 @@ sub munge_script {
 
     # the --json output is so that we can read the list of included modules
     my @depak_cmd = (
-        "depak", "--include-dir", $mods_tempdir,
+        "depak",
+        "--include-dir", $mods_tempdir,
         "-i", $source, "-o", $target, "--overwrite",
         "--json",
     );
 
     if (-f "depak.conf") {
-        push @depak_cmd, "--config-path", "depak.conf";
+        push @depak_cmd, (
+            "--config-profile", $profile,
+            "--config-path", "depak.conf",
+        );
     }
 
     $self->log_debug(["Depak-ing %s: %s", $file->{name}, \@depak_cmd]);
@@ -183,7 +189,7 @@ Dist::Zilla::Plugin::Depak - Pack dependencies onto scripts during build using '
 
 =head1 VERSION
 
-This document describes version 0.12 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2015-07-07.
+This document describes version 0.13 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2015-07-27.
 
 =head1 SYNOPSIS
 
